\name{mdp-package}
\alias{mdp-package}
\docType{package}
\title{
  Dirichlet process mixture (MDP) of normal model.
}
\description{
  The package implements posterior inference for MDP models
  with multivariate normal kernel and conjugate DP base measure.
  The mixture is with respect to both, mean and covariance matrix of the
  kernel. 
  The package includes posterior predictive inference for one- and
  two-dimensional subvectors, and posterior predictive mean functions
  and surfaces for two and three-dimensional subvectors.
}
\details{
\tabular{ll}{
  Package: \tab mdp\cr
  Type: \tab Package\cr
  Version: \tab 1.0\cr
  Date: \tab 2007-04-01\cr
  License: \tab GNU public domain software.\cr
}
The function \code{mdp} implements posterior MCMC simulation.
The function assumes a conditionally conjugate MDP model, with conjugate
kernel and Dirichlet process base measure.
The functions \code{plt.pxy}, \code{plt.exy} and \code{plt.ex}
plot posterior predictive inference.

The package uses the model described in
\cite{MacEachern and Mueller (1998)}.
Let \eqn{y_i \sim H(y)} denote an i.i.d. sample from an unknown
distribution \eqn{H(y)}.
We model the random probability measure \eqn{H} as a location and scale
mixture of multivariate normal kernels,
\deqn{
  H(y) = \int N(\mu,V) dG(\mu,V)
}
with a Dirichlet process (DP) prior for the mixing measure,
\eqn{G \sim DP(G_0,\alpha)} and a conditionally conjugate base measure
\eqn{G_0(\mu,V^{-1})=G_{\mu0}(\mu) G_{V0}(V^{-1})} where
\deqn{
  G_{\mu0}(\mu) = N(m,B) \mbox{ and } G_{V0}(V^{-1})=Wishart(s,(sS)^{-1}).
}
The Wishart distribution is parametrized such that \eqn{E(V_{-1})=S^{-1}}.
We assume conjugate hyperpriors
\deqn{
  m \sim N(a,A), B^{-1} \sim Wishart(c,(cC)^{-1}),
  S \sim Wishart(q, R/q).
}
The model is completed with a Gamma prior for the total mass paramter
\eqn{\alpha \sim Ga(a_0,b_0)}.


}
\author{
Peter Mueller

Maintainer: Peter Mueller <pm@wotan.mdacc.tmc.edu>
}
\references{
  The package uses the parametrization defined in:
  
    MacEachern, S.N. and Mueller, P. (1998).
  ``Estimating Mixture of Dirichlet Process Models,''
 Journal of Computational and Graphical Statistics, 7, 223--239.
}
\keyword{ package }
\seealso{See also the package \code{\link{DPpackage}}, at
  
  \url{http://student.kuleuven.be/~s0166452/software.html}.

}
