\name{plt.pxy}
\alias{plt.pxy}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Bivariate posterior predictive}
\description{
  Plots the bivariate density estimate
  \eqn{p(x,y) = E[ H(x,y) \mid data] }.
}
\usage{
plt.pxy <- function(xlab="X",ylab="Y",
                    xlim=NULL,ylim=NULL,
                    lg=F,    
                    img=T)   
}
\arguments{
  \item{xlab}{label on the x-axis}
  \item{ylab}{label on the y-axis}
  \item{xlim}{domain of the x-axis}
  \item{ylim}{domain of the y-axis}
  \item{lg}{plot log density}
  \item{img}{indicator for image plot vs. contours}
}
\details{
  Need to call \code{\link{mdp}} first to carry out the posterior Markov
  chain Monte Carlo simulation. The function \code{plt.pxy} uses
  the simulation output to produce the desired posterior predictive
  distribution.
  The function assumes the simulation output is saved in the current
  working directory. Change it by using \code{setwd} if necessary.
  
  See   \code{\link{mdp-package}}  for a statement of the probability
  model for the random probability measure \eqn{H}.
  Here \eqn{H(.)} is the random probability distribution modeled
  by the DP mixture of normals.
  See \code{\link{mdp-package}} for a statement.
}
\value{
  The function returns no value.
}
\references{
  the package uses the parametrization defined in:
  
    MacEachern, S.N. and Mueller, P. (1998).
  ``Estimating Mixture of Dirichlet Process Models,''
 Journal of Computational and Graphical Statistics, 7, 223--239.
}
\author{Peter Mueller \email{pmueller@math.utexas.edu}}
\note{Careful, \code{mdp} writes temporary files
  into the current working directory. The same files
  are used by \code{plt.pxy}, \code{plt.ex} and \code{plt.exy}
  to plot posterior predictive distributions and expectations.
}
\seealso{See also the R library \code{\link{DPpackage}}, at
  
  \url{http://student.kuleuven.be/~s0166452/software.html}.}
\examples{
\dontrun{
## Data from Lubischew, A. (1962), "On the use of discriminant functions
##           in taxonomy," Biometrics, 18, 455-477.
data.dir <- system.file("demo",package="mdp")
beetles <- file.path(data.dir,"beetle.data")
Y <- read.table(beetles)   # beetle data. The last column reports species
p <- ncol(Y)         
Y <- as.matrix(Y[,-p]) # don't use the species indicator

## run MCMC
##
mdp(Y=Y,
    pxy=1,exy=1,ex=1,ix=1,iy=2,iz=3,
    q=10,cc=10)

## plot results
##
plt.pxy(img=T,lg=T)         ## biv density estimate p(x,y), 
                            ## x=1st col (ix), y=2nd column (iy)
points(Y[,1],Y[,2],pch=19)  # add data points

plt.pxy(img=F,lg=F)         # same as a contour plot
points(Y[,1],Y[,2],pch=19)

plt.ex(sd=T)                ## E(z | x, data), for z=3rd col (iz)
plt.ex(sim=T)               ## show random draws from p(f | data)

plt.exy()                   ## E(z | x,y, data)

## note: for marginals on different coordinates need to
## re-run mdp with new values for ix,iy,iz
}
}
